==> apache-iotdb-1.2.2-source-release.zip: apache-iotdb-1.2.2/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/schemaengine/schemaregion/read/req/impl/ShowDevicesPlanImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.iotdb.db.schemaengine.schemaregion.read.req.impl;

import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.commons.schema.filter.SchemaFilter;
import org.apache.iotdb.db.schemaengine.schemaregion.read.req.IShowDevicesPlan;

import java.util.Objects;

public class ShowDevicesPlanImpl extends AbstractShowSchemaPlanImpl implements IShowDevicesPlan {

  // templateId > -1 means the device should use template with given templateId
  private final int schemaTemplateId;
  private final SchemaFilter schemaFilter;

  public ShowDevicesPlanImpl(
      PartialPath path,
      long limit,
      long offset,
      boolean isPrefixMatch,
      int schemaTemplateId,
      SchemaFilter schemaFilter) {
    super(path, limit, offset, isPrefixMatch);
    this.schemaTemplateId = schemaTemplateId;
    this.schemaFilter = schemaFilter;
  }

  @Override
  public SchemaFilter getSchemaFilter() {
    return schemaFilter;
  }

  @Override
  public boolean usingSchemaTemplate() {
    return schemaTemplateId != -1;
  }

  @Override
  public int getSchemaTemplateId() {
    return schemaTemplateId;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ShowDevicesPlanImpl that = (ShowDevicesPlanImpl) o;
    return schemaTemplateId == that.schemaTemplateId;
  }

  @Override
  public int hashCode() {
    return Objects.hash(super.hashCode(), schemaTemplateId);
  }
}

==> apache-iotdb-1.3.4-1-source-release.zip: apache-iotdb-1.3.4-1/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/schemaengine/schemaregion/read/req/impl/ShowDevicesPlanImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.iotdb.db.schemaengine.schemaregion.read.req.impl;

import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.commons.path.PathPatternTree;
import org.apache.iotdb.commons.schema.filter.SchemaFilter;
import org.apache.iotdb.db.schemaengine.schemaregion.read.req.IShowDevicesPlan;

import java.util.Objects;

public class ShowDevicesPlanImpl extends AbstractShowSchemaPlanImpl implements IShowDevicesPlan {

  // templateId > -1 means the device should use template with given templateId
  private final int schemaTemplateId;
  private final SchemaFilter schemaFilter;

  public ShowDevicesPlanImpl(
      PartialPath path,
      long limit,
      long offset,
      boolean isPrefixMatch,
      int schemaTemplateId,
      SchemaFilter schemaFilter,
      PathPatternTree scope) {
    super(path, limit, offset, isPrefixMatch, scope);
    this.schemaTemplateId = schemaTemplateId;
    this.schemaFilter = schemaFilter;
  }

  @Override
  public SchemaFilter getSchemaFilter() {
    return schemaFilter;
  }

  @Override
  public boolean usingSchemaTemplate() {
    return schemaTemplateId != -1;
  }

  @Override
  public int getSchemaTemplateId() {
    return schemaTemplateId;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ShowDevicesPlanImpl that = (ShowDevicesPlanImpl) o;
    return schemaTemplateId == that.schemaTemplateId;
  }

  @Override
  public int hashCode() {
    return Objects.hash(super.hashCode(), schemaTemplateId);
  }
}
